/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.2 Straßensubsegmentanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.subsegana.subsegana;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.junit.BeforeClass;
import org.junit.Test;

import com.bitctrl.resource.Configuration;
import com.bitctrl.util.logging.LoggerTools;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.umfelddaten.OdUfdmsGlaetteFuzzy;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.umfelddaten.OdUfdsHelligkeitFuzzy;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.umfelddaten.OdUfdsNiederschlagsIntensitaetFuzzy;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.umfelddaten.OdUfdsSichtWeiteFuzzy;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.umfelddaten.OdUfdsWindGeschwindigkeitMittelWertFuzzy;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.umfelddaten.OdUfdsWindRichtungFuzzy;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.verkehr.OdAnteilLkw;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.verkehr.OdBemessungsDichte;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.verkehr.OdGeschwindkeit;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.verkehr.OdVerkehrsStaerkeStunde;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.verkehr.OdVerkehrsUnruhe;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.verkehr.OdVerkehrsZustand;
import de.bsvrz.iav.fuzzylib.fuzzylib.modell.verkehr.OdVerkehrsZustandUnruhe;
import de.bsvrz.sys.funclib.bitctrl.modell.ObjektFactory;
import de.bsvrz.sys.funclib.bitctrl.modell.SystemObjekt;
import de.bsvrz.sys.funclib.bitctrl.modell.umfelddaten.objekte.UfdsHelligkeit;
import de.bsvrz.sys.funclib.bitctrl.modell.umfelddaten.objekte.UfdsNiederschlagsIntensitaet;
import de.bsvrz.sys.funclib.bitctrl.modell.umfelddaten.objekte.UfdsSichtWeite;
import de.bsvrz.sys.funclib.bitctrl.modell.umfelddaten.objekte.UmfeldDatenMessStelle;
import de.bsvrz.sys.funclib.bitctrl.modell.umfelddaten.onlinedaten.OdUfdmsGlaette;
import de.bsvrz.sys.funclib.bitctrl.modell.umfelddaten.onlinedaten.OdUfdsHelligkeit;
import de.bsvrz.sys.funclib.bitctrl.modell.umfelddaten.onlinedaten.OdUfdsNiederschlagsIntensitaet;
import de.bsvrz.sys.funclib.bitctrl.modell.umfelddaten.onlinedaten.OdUfdsSichtWeite;
import de.bsvrz.sys.funclib.bitctrl.modell.umfelddaten.onlinedaten.OdUfdsWindGeschwindigkeitMittelWert;
import de.bsvrz.sys.funclib.bitctrl.modell.umfelddaten.onlinedaten.OdUfdsWindRichtung;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.onlinedaten.OdVerkehrsDatenKurzZeitMq;

/**
 * Führt den Prüffall 7 <em>Fuzzy-Technologie</em> aus.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
@SuppressWarnings("nls")
public class Prueffall7 {

	/** Der Logger der Klassse. */
	private static Logger log = Logger.getLogger(Prueffall7.class.getName());

	/**
	 * Initialisiert den Testfall.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@BeforeClass
	public static void beforeClass() throws Exception {
		final ObjektFactory factory;
		final ClientDavConnection verbindung;
		final Configuration konfig;
		final Level level;

		konfig = Configuration.getConfiguration();
		level = Level.parse(konfig.getString("debug.level"));
		LoggerTools.setLoggerLevel(level);
		log.setLevel(level);

		log.info("Stelle Verbindung zum Datenverteiler her ...");
		verbindung = new ClientDavConnection();
		verbindung.getClientDavParameters()
				.setDavCommunicationAddress(konfig.getString("dav.host"));
		verbindung.getClientDavParameters()
				.setDavCommunicationSubAddress(konfig.getInt("dav.port"));
		verbindung.connect();
		verbindung.login(konfig.getString("dav.benutzer"),
				konfig.getString("dav.kennwort"));

		factory = ObjektFactory.getInstanz();
		factory.setVerbindung(verbindung);
		factory.registerStandardFactories();
	}

	/**
	 * Testet die Fuzzyfizierung der Helligkeit.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testHelligkeit() throws Exception {
		final Testfall<OdUfdsHelligkeit.Daten> datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info("Starte Test für die Fuzzyfizierung der Helligkeit ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.ufds_hk"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallFuzzyfizierung<>(obj,
				"Helligkeit", OdUfdsHelligkeit.class,
				OdUfdsHelligkeit.Aspekte.MessWertErsetzung.getAspekt(),
				OdUfdsHelligkeitFuzzy.class);
		assertEquals(12, datum.getSollWerte().size());
		assertEquals(12, datum.getTestdaten().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Fuzzyfizierung der Niederschlagsintensität.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testNiederschlagsIntensitaet() throws Exception {
		final Testfall<OdUfdsNiederschlagsIntensitaet.Daten> datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info(
				"Starte Test für die Fuzzyfizierung der Niederschlagsintensität ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.ufds_ni"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallFuzzyfizierung<>(
				obj, "NiederschlagsIntensität",
				OdUfdsNiederschlagsIntensitaet.class,
				OdUfdsNiederschlagsIntensitaet.Aspekte.MessWertErsetzung
				.getAspekt(),
				OdUfdsNiederschlagsIntensitaetFuzzy.class);
		assertEquals(13, datum.getSollWerte().size());
		assertEquals(13, datum.getTestdaten().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Fuzzyfizierung der Sichtweite.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testSichtWeite() throws Exception {
		final Testfall<OdUfdsSichtWeite.Daten> datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info("Starte Test für die Fuzzyfizierung der Sichtweite ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.ufds_sw"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallFuzzyfizierung<>(obj,
				"SichtWeite", OdUfdsSichtWeite.class,
				OdUfdsSichtWeite.Aspekte.MessWertErsetzung.getAspekt(),
				OdUfdsSichtWeiteFuzzy.class);
		assertEquals(17, datum.getSollWerte().size());
		assertEquals(17, datum.getTestdaten().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Fuzzyfizierung der Glätte.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testGlaette() throws Exception {
		final Testfall<OdUfdmsGlaette.Daten> datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info("Starte Test für die Fuzzyfizierung der Sichtweite ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.ufdm"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallFuzzyfizierung<>(obj, "Glätte",
				OdUfdmsGlaette.class,
				OdUfdmsGlaette.Aspekte.Prognose.getAspekt(),
				OdUfdmsGlaetteFuzzy.class);
		assertEquals(12, datum.getSollWerte().size());
		assertEquals(12, datum.getTestdaten().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Fuzzyfizierung der mittleren Windgeschwindigkeit.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testWindGeschwindigkeitMittelWert() throws Exception {
		final Testfall<OdUfdsWindGeschwindigkeitMittelWert.Daten> datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info(
				"Starte Test für die Fuzzyfizierung der Windgeschwindigkeit ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.ufds_wgm"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallFuzzyfizierung<>(
				obj, "WindGeschwindigkeitMittelWert",
				OdUfdsWindGeschwindigkeitMittelWert.class,
				OdUfdsWindGeschwindigkeitMittelWert.Aspekte.MessWertErsetzung
				.getAspekt(),
				OdUfdsWindGeschwindigkeitMittelWertFuzzy.class);
		assertEquals(10, datum.getSollWerte().size());
		assertEquals(10, datum.getTestdaten().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Fuzzyfizierung der Windrichtung.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testWindRichtung() throws Exception {
		final Testfall<OdUfdsWindRichtung.Daten> datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info("Starte Test für die Fuzzyfizierung der Windrichtung ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.ufds_wr"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallFuzzyfizierung<>(obj,
				"WindRichtung", OdUfdsWindRichtung.class,
				OdUfdsWindRichtung.Aspekte.MessWertErsetzung.getAspekt(),
				OdUfdsWindRichtungFuzzy.class);
		assertEquals(24, datum.getSollWerte().size());
		assertEquals(24, datum.getTestdaten().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Fuzzyfizierung des Lkw-Anteils.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testALkw() throws Exception {
		final Testfall<OdVerkehrsDatenKurzZeitMq.Daten> datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info("Starte Test für die Fuzzyfizierung des Lkw-Anteils ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.mq"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallFuzzyfizierung<>(obj,
				"ALkw", OdVerkehrsDatenKurzZeitMq.class,
				OdVerkehrsDatenKurzZeitMq.Aspekte.Analyse.getAspekt(),
				OdAnteilLkw.class);
		assertEquals(14, datum.getSollWerte().size());
		assertEquals(14, datum.getTestdaten().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Fuzzyfizierung der Bemessungsdichte.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testKB() throws Exception {
		final Testfall<OdVerkehrsDatenKurzZeitMq.Daten> datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info("Starte Test für die Fuzzyfizierung der Bemessungsdichte ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.mq"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallFuzzyfizierung<>(obj,
				"KB", OdVerkehrsDatenKurzZeitMq.class,
				OdVerkehrsDatenKurzZeitMq.Aspekte.Analyse.getAspekt(),
				OdBemessungsDichte.class);
		assertEquals(8, datum.getSollWerte().size());
		assertEquals(8, datum.getTestdaten().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Fuzzyfizierung der Verkehrsstärke.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testQKfz() throws Exception {
		final Testfall<OdVerkehrsDatenKurzZeitMq.Daten> datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info("Starte Test für die Fuzzyfizierung der Verkehrsstärke ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.mq"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallFuzzyfizierung<>(obj,
				"QKfz", OdVerkehrsDatenKurzZeitMq.class,
				OdVerkehrsDatenKurzZeitMq.Aspekte.Analyse.getAspekt(),
				OdVerkehrsStaerkeStunde.class);
		assertEquals(14, datum.getSollWerte().size());
		assertEquals(14, datum.getTestdaten().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Fuzzyfizierung der Standardabweichung der
	 * Kfz-Geschwindigkeiten.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testSKfz() throws Exception {
		final Testfall<OdVerkehrsDatenKurzZeitMq.Daten> datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info(
				"Starte Test für die Fuzzyfizierung der Standardabweichung der Kfz-Geschwindigkeiten ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.mq"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallFuzzyfizierung<>(obj,
				"SKfz", OdVerkehrsDatenKurzZeitMq.class,
				OdVerkehrsDatenKurzZeitMq.Aspekte.Analyse.getAspekt(),
				OdVerkehrsUnruhe.class);
		assertEquals(5, datum.getSollWerte().size());
		assertEquals(5, datum.getTestdaten().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Fuzzyfizierung der Geschwindigkeit.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testVKfz() throws Exception {
		final Testfall<OdVerkehrsDatenKurzZeitMq.Daten> datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info("Starte Test für die Fuzzyfizierung der Geschwindigkeit ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.mq"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallFuzzyfizierung<>(obj,
				"VKfz", OdVerkehrsDatenKurzZeitMq.class,
				OdVerkehrsDatenKurzZeitMq.Aspekte.Analyse.getAspekt(),
				OdGeschwindkeit.class);
		assertEquals(8, datum.getSollWerte().size());
		assertEquals(8, datum.getTestdaten().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Regelbasis für den Verkehrszustand.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testRegelnVerkehrsZustand() throws Exception {
		final TestfallRegelnVerkehrsmodell datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info("Starte Test für die Regelbasis des Verkehrszustands ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.mq"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallRegelnVerkehrsmodell(obj, "VerkehrsZustand",
				OdVerkehrsZustand.class);
		assertEquals(63, datum.getSollWerte().size());
		assertEquals(64, datum.getTestdaten().size());
		datum.ausfuehren();

		// Augenblick warten, damit Nachzüglerdaten ankommen können
		ObjektFactory.getInstanz().getVerbindung().sleep(100);

		log.fine("Auf Eingang aller Ist-Werte warten ...");
		// Die Menge der Ist-Werte muss um 1 größer sein, als die der Soll-Werte
		while (datum.getIstWerte().size() <= datum.getSollWerte().size()) {
			Thread.yield();
		}
		datum.getIstWerte().remove(datum.getIstWerte().firstKey());
		datum.auswerten();
	}

	/**
	 * Testet die Regelbasis für die Unruhe im Verkehrsfluss.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testRegelnVerkehrsZustandUnruhe() throws Exception {
		final TestfallRegelnVerkehrsmodell datum;
		final SystemObjekt obj;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info(
				"Starte Test für die Regelbasis der Unruhe im Verkehrsfluss ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		obj = factory.getModellobjekt(konfig.getString("objekt.mq"));
		assertNotNull("Das Testobjekt existiert nicht.", obj);

		datum = new TestfallRegelnVerkehrsmodell(obj, "VerkehrsZustandUnruhe",
				OdVerkehrsZustandUnruhe.class);
		assertEquals(70, datum.getSollWerte().size());
		assertEquals(70, datum.getTestdaten().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Regelbasis für den Fahrbahnzustand.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testRegelnFahrBahnZustand() throws Exception {
		final TestfallRegelnFahrBahnZustand datum;
		final UmfeldDatenMessStelle ufdm;
		final UfdsNiederschlagsIntensitaet ufdsNi;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info("Starte Test für die Regelbasis den Fahrbahnzustand ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();
		ufdm = (UmfeldDatenMessStelle) factory
				.getModellobjekt(konfig.getString("objekt.ufdm"));
		assertNotNull("Das Testobjekt existiert nicht.", ufdm);
		ufdsNi = (UfdsNiederschlagsIntensitaet) factory
				.getModellobjekt(konfig.getString("objekt.ufds_ni"));
		assertNotNull("Das Testobjekt existiert nicht.", ufdsNi);

		datum = new TestfallRegelnFahrBahnZustand(ufdm, ufdsNi);
		assertEquals(26, datum.getSollWerte().size());
		assertEquals(26, datum.getTestdatenGlaette().size());
		assertEquals(26, datum.getTestdatenNi().size());
		datum.ausfuehren();
		datum.auswerten();
	}

	/**
	 * Testet die Regelbasis für die Sichtverhältnisse.
	 *
	 * @throws Exception
	 *             bei einem Fehler.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void testRegelnSichtVerhaeltnisse() throws Exception {
		final TestfallRegelnSichtVerhaeltnisse datum;
		final UmfeldDatenMessStelle ufdm;
		final UfdsNiederschlagsIntensitaet ufdsNi;
		final UfdsHelligkeit ufdsHK;
		final UfdsSichtWeite ufdsSW;
		final ObjektFactory factory;
		final Configuration konfig;

		log.info("Starte Test für die Regelbasis der Sichtverhältnisse ...");

		konfig = Configuration.getConfiguration();
		factory = ObjektFactory.getInstanz();

		ufdm = (UmfeldDatenMessStelle) factory
				.getModellobjekt(konfig.getString("objekt.ufdm"));
		assertNotNull("Das Testobjekt existiert nicht.", ufdm);

		ufdsNi = (UfdsNiederschlagsIntensitaet) factory
				.getModellobjekt(konfig.getString("objekt.ufds_ni"));
		assertNotNull("Das Testobjekt existiert nicht.", ufdsNi);

		ufdsHK = (UfdsHelligkeit) factory
				.getModellobjekt(konfig.getString("objekt.ufds_hk"));
		assertNotNull("Das Testobjekt existiert nicht.", ufdsHK);

		ufdsSW = (UfdsSichtWeite) factory
				.getModellobjekt(konfig.getString("objekt.ufds_sw"));
		assertNotNull("Das Testobjekt existiert nicht.", ufdsSW);

		datum = new TestfallRegelnSichtVerhaeltnisse(ufdm, ufdsNi, ufdsHK,
				ufdsSW);
		assertEquals(2652, datum.getSollWerte().size());
		assertEquals(2652, datum.getTestdatenHK().size());
		assertEquals(2652, datum.getTestdatenNi().size());
		assertEquals(2652, datum.getTestdatenSW().size());
		datum.ausfuehren();
		datum.auswerten();
	}

}
